function mcr = computeMeanClusterRecall(G, C)
    % Computes the mean cluster recall of the clustering C wrt. the ground truth clustering G
    % Usage:
    %         mcr = computeMeanClusterRecall(G, C)
    % Input:
    %     G - a COLUMN vector of ground truth cluster assignments for each image. -1 means no assignment.
    %     C - a COLUMN vector of cluster assignments for each image you came up with. -1 means no assignment.
    % Output:
    %     mcr - the mean cluster recall value.
    Ng = sum(G>=0);
    clusters_g = unique(G);
    clusters_g = clusters_g(clusters_g ~= -1);
    p = 0;
    for g = clusters_g'
        gt_cluster_imgs = G==g;
        gt_cluster_assignments = C(gt_cluster_imgs);
        gt_cluster_assignments = gt_cluster_assignments(gt_cluster_assignments ~= -1);
        if ~isempty(gt_cluster_assignments)
            [~, n] = mode(gt_cluster_assignments);
            p = p + n;
        end
    end
    mcr = p / Ng;
end
