#!/usr/bin/python
#
# Download script for the MMP Paris Dataset
#
# 2010 by Tobias Weyand
# 

import sys, os, urllib, Image
from flickrapi2 import FlickrAPI

flickr_api_key = "YOUR API KEY HERE"
flickr_secret = "YOUR SECRET HERE"

def jpg_ok(jpg):
    if not os.path.exists(jpg):
        return false
    f = open(jpg)
    s = f.read(2)
    f.close()
    return s == '\xff\xd8'

if __name__ == "__main__":

    if flickr_api_key == "YOUR API KEY HERE" or flickr_secret == "YOUR SECRET HERE":
        print "Please edit the script and add your Flickr API Key and secret."
        sys.exit(1)

    if len(sys.argv) != 2:
        print "Syntax: %s images_flickr.txt" % sys.argv[0]
        sys.exit(0)

    filelist = sys.argv[1]

    if not os.path.exists(filelist):
        print "Could not find %s" % filelist
        sys.exit(1)

    files_flickr = [l.strip().split()[0] for l in open(filelist).readlines()]

    flog = open(filelist + ".log", "w")

    def log(s):
        flog.write(s + "\n")
        print s

    cwd = os.getcwd()
    basedir = os.path.join(cwd, os.path.basename(filelist).replace(".txt",""))
    if not os.path.exists(basedir):
        os.mkdir(basedir)

    fapi = FlickrAPI(flickr_api_key, flickr_secret)

    filecounter = 0
    foldercounter = 0
    for file in files_flickr:
        if filecounter % 500 == 0:
            foldercounter += 1
            currfolder = os.path.join(basedir, str(foldercounter).rjust(5,'0'))
            if not os.path.exists(currfolder):
                os.mkdir(currfolder)

        file = file.split(".")[0]
        (photoid, secret, server, userid) = file.split("_")
        try:
            resp = fapi.photos_getSizes(api_key = flickr_api_key, photo_id = photoid)
        except:
            log("Error requesting available image sizes")
            continue

        if resp["stat"] == "fail":
            log("Could not download %s !" % file)
            log("Flickr said: \"%s\"" % resp.err[0]["msg"])
            continue

        # Try to get the "Large" size since it's 1024x768
        large = [s for s in resp.sizes[0].size if s["label"] == "Large"]
        if len(large) == 0:
            # Else just get the biggest one
            n_sizes = len(resp.sizes[0].size)
            node = resp.sizes[0].size[n_sizes - 1]
        else:
            node = large[0]

        img_url = node["source"]
        log(img_url)

        jpgfile = os.path.join(currfolder, file + ".jpg")
        urllib.urlretrieve(img_url, jpgfile)

        retry = 0
        while ( not jpg_ok(jpgfile) ) and retry < 5:
            log("Oops, file broken. Retrying.")
            urllib.urlretrieve(img_url, jpgfile)
            retry += 1

        if retry > 0:
            if jpg_ok(jpgfile):
                log("File retrieved successfully.")
            else:
                log("Didn't work out. Giving up.")
                if os.path.exists(jpgfile):
                    os.remove(jpgfile)
                continue

        img = Image.open(jpgfile)
        max_size = max(img.size)

        if max_size >= 1024:
            try:
                scale = 1024.0 / max_size
                newsize = (int(img.size[0] * scale), int(img.size[1]*scale))
                img.resize(newsize, resample=Image.ANTIALIAS)
                img.save(jpgfile)
            except:
                log("Failed to scale image!")

        filecounter += 1

    flog.close()
